@@ -2,16 +2,11 @@ from dataclasses import dataclass, field
 from datetime import datetime
 from typing import List, Optional, Union
 
-from dataclasses_json.api import dataclass_json
+from dataclasses_json.api import DataClassJsonMixin, dataclass_json
 from dataclasses_json.cfg import config
 from stringcase import camelcase
 
-
-def datetime_encoder(dt: Optional[datetime] = None) -> Optional[str]:
-    if dt is None:
-        return None
-
-    return dt.isoformat()
+from ..encoders import datetime_encoder, reject_none_encoder
 
 
 @dataclass_json(letter_case=camelcase)
@@ -74,8 +69,8 @@ class Cookie:
             encoder=datetime_encoder,
         ),
     )
-    http_only: Optional[bool] = None
-    secure: Optional[bool] = None
+    http_only: bool = False
+    secure: bool = False
     same_site: Optional[str] = None
 
 
@@ -135,8 +130,9 @@ class Response:
     body_size: int
     redirect_url: str = field(metadata=config(field_name="redirectURL"))
     comment: Optional[str] = None
-    _remote_ip_address: Optional[str] = field(
-        default=None, metadata=config(field_name="_remoteIPAddress")
+
+    _transfer_size: Optional[int] = field(
+        default=None, metadata=config(field_name="_transferSize")
     )
 
 
@@ -153,6 +149,16 @@ class Timings:
     comment: Optional[Union[int, float]] = None
 
 
+@dataclass_json(letter_case=camelcase)
+@dataclass
+class SecurityDetails:
+    protocol: Optional[str] = None
+    subject_name: Optional[str] = None
+    issuer: Optional[str] = None
+    valid_from: Optional[int] = None
+    valid_to: Optional[int] = None
+
+
 @dataclass_json(letter_case=camelcase)
 @dataclass
 class Entry:
@@ -172,6 +178,13 @@ class Entry:
     )
     comment: Optional[str] = None
 
+    _server_port: Optional[int] = field(
+        default=None, metadata=config(field_name="_serverPort")
+    )
+    _security_details: Optional[SecurityDetails] = field(
+        default=None, metadata=config(field_name="_securityDetails")
+    )
+
 
 @dataclass_json(letter_case=camelcase)
 @dataclass
@@ -202,7 +215,10 @@ class Log:
     comment: Optional[str] = None
 
 
-@dataclass_json(letter_case=camelcase)
 @dataclass
-class Har:
-    log: Log
+class Har(DataClassJsonMixin):
+    log: Log = field(
+        metadata=config(
+            encoder=reject_none_encoder,
+        ),
+    )
